# Official Python SDK for Continual

https://www.continual.ai

## Getting Started

to install the continual SDK and cli run:

```
pip3 install --no-cache-dir https://storage.googleapis.com/continual-public/sdk/continual-0.1.0.tar.gz
```
